diff mbox series

[v2] libceph: advancing variants of iov_iter_get_pages()

Message ID 20220817125904.101285-1-xiubli@redhat.com (mailing list archive)
State New, archived
Headers show
Series [v2] libceph: advancing variants of iov_iter_get_pages() | expand

Commit Message

Xiubo Li Aug. 17, 2022, 12:59 p.m. UTC
From: Xiubo Li <xiubli@redhat.com>

The upper layer has changed it to iov_iter_get_pages2(). And this
should be folded into the previous commit.

Reviewed-by: Jeff Layton <jlayton@kernel.org>
Signed-off-by: Xiubo Li <xiubli@redhat.com>
---
 net/ceph/messenger.c | 18 ++++++------------
 1 file changed, 6 insertions(+), 12 deletions(-)
diff mbox series

Patch

diff --git a/net/ceph/messenger.c b/net/ceph/messenger.c
index 945f6d1a9efa..6caf8a2ff4ae 100644
--- a/net/ceph/messenger.c
+++ b/net/ceph/messenger.c
@@ -985,24 +985,18 @@  static struct page *ceph_msg_data_iter_next(struct ceph_msg_data_cursor *cursor,
 	if (cursor->lastlen)
 		iov_iter_revert(&cursor->iov_iter, cursor->lastlen);
 
-	len = iov_iter_get_pages(&cursor->iov_iter, &page, PAGE_SIZE,
-				 1, page_offset);
+	len = iov_iter_get_pages2(&cursor->iov_iter, &page, PAGE_SIZE,
+				  1, page_offset);
 	BUG_ON(len < 0);
 
 	cursor->lastlen = len;
 
-	/*
-	 * FIXME: Al Viro says that he will soon change iov_iter_get_pages
-	 * to auto-advance the iterator. Emulate that here for now.
-	 */
-	iov_iter_advance(&cursor->iov_iter, len);
-
 	/*
 	 * FIXME: The assumption is that the pages represented by the iov_iter
 	 * 	  are pinned, with the references held by the upper-level
 	 * 	  callers, or by virtue of being under writeback. Eventually,
 	 * 	  we'll get an iov_iter_get_pages variant that doesn't take page
 	 * 	  refs. Until then, just put the page ref.
 	 */
 	VM_BUG_ON_PAGE(!PageWriteback(page) && page_count(page) < 2, page);
 	put_page(page);
@@ -985,24 +985,18 @@  static struct page *ceph_msg_data_iter_next(struct ceph_msg_data_cursor *cursor,
 	/*
 	 * FIXME: The assumption is that the pages represented by the iov_iter
-	 * 	  are pinned, with the references held by the upper-level
-	 * 	  callers, or by virtue of being under writeback. Eventually,
-	 * 	  we'll get an iov_iter_get_pages variant that doesn't take page
-	 * 	  refs. Until then, just put the page ref.
+	 *	  are pinned, with the references held by the upper-level
+	 *	  callers, or by virtue of being under writeback. Eventually,
+	 *	  we'll get an iov_iter_get_pages2 variant that doesn't take page
+	 *	  refs. Until then, just put the page ref.
 	 */
 	VM_BUG_ON_PAGE(!PageWriteback(page) && page_count(page) < 2, page);